/* MAUSDEMO.CPP                                                            */
/* Copyright (C) 1993, Birnensoft Communications, alle Rechte vorbehalten  */

#include "birnbaum.h"
#include <dos.h>
#include <bios.h>
#include <stdlib.h>

/* GLOBALE DEKLARATIONEN                                                   */
/* Anstatt #define-Direktiven werden Konstantevariablen deklariert, wie es */
/* in der modernen C++-Programmierarbeit blich ist.  Konstantevariablen   */
/* belegen keinen theoretischen Speicher und verursachen keine von den     */
/* Problemen mit Debuggern und Profilern, die oft bei der Nutzung von      */
/* Prprozessordirektiven vorkommen.                                       */

extern int _wscroll;
const int STILLSTAND = 0;             /* Constantevariablen anstatt       */
const int RECHTS = 1;                 /* #define-Direktiven.              */
const int LINKS = 2;
const int AUFWAERTS = 3;
const int ABWAERTS = 4;
const int ESC = 27;

/* ENDE Globaledeklarationen --------------------------------------------- */

/* *********************************************************************** */

/* Hauptverarbeitungsfunktion verarbeitung() ----------------------------- */

void verarbeitung(void)
{
    int waagerecht, senkrecht;
    int x, y, xx, yy, schalter = NULL;        /* Schaltervorgabewert NULL, */
                                              /* um 1. Lauf durch die      */
                                              /* while-Schleife zu ermg-  */
                                              /* lichen.                   */

    _setcursortype(_NOCURSOR);                /* Textcursor ausschalten!!  */
                                              /* In diesem Fenster sind    */
                                              /* Eingaben und Cursor uner- */
                                              /* wnscht!                  */

    maus_neu_setzen();                        /* Maus initialisieren       */
    maus_zeiger_ein();                        /* Mauszeiger anschalten     */

    while(schalter != ESC)            /* Solange bis [ESC]-Taste bettigt  */
    {                                 /* wird                              */

        /* Meldung wird gezeigt, da linke Maustaste angeklickt wurde      */

        if(maus_klick_links()&& !maus_klick_rechts())
        {
            ausgabe_wo(21,17);
            textattr(47);
            cprintf("Linke Maustaste angeklickt ");
            textattr(23);
        }

        /* Meldung wird gezeigt, da rechte Maustaste angeklickt wurde     */

        if(maus_klick_rechts() && !maus_klick_links())
        {
            ausgabe_wo(21,17);
            textattr(47);
            cprintf("Rechte Maustaste angeklickt");
            textattr(23);
        }

        /* Meldung wird gezeigt, da beide Maustasten angeklickt wurden   */

        if(maus_klick_links() && maus_klick_rechts())
        {
            ausgabe_wo(21,17);
            textattr(47);
            cprintf("Beide Maustasten angeklickt");
            textattr(23);
        }

        /* Die Mausposition wird nun auf dem Bildschirm  gezeigt          */

        maus_wo(&x, &y);
        ausgabe_wo(21,5);
        textattr(31);
        cprintf("Mausposition in Mickeys:");
        ausgabe_wo(21,6);
        textattr(30);
        cprintf("Spalte %06d, Zeile %06d", x, y);
        ausgabe_wo(21,8);
        textattr(31);
        cprintf("Mausposition: Textmodus:");
        if(!x)
           xx = 1;
        else
           xx = (x / 8)+1;
        if(!y)
           yy = 1;
        else
           yy = (y / 8)+1;
        ausgabe_wo(21,9);
        textattr(30);
        cprintf("Spalte %06d, Zeile %06d", xx, yy);
        textattr(23);
        ausgabe_wo(0,0);

       /* Kontrollieren, ob Mausposition sich gendert hat                */

        maus_bewegung(&waagerecht, &senkrecht);

        ausgabe_wo(21,11);
        textattr(31);
        cprintf("Waagerechte Richtung: ");
        ausgabe_wo(21,14);
        cprintf("Senkrechte Richtung: ");

        /* Wurde senkrechte bzw. waagerechte Bewegung entdeckt?           */

        if(waagerecht || senkrecht)
        {
            ausgabe_wo(21,12);
            textattr(30);

            switch(waagerecht)
            {
                case STILLSTAND:
                    cprintf("      ");
                    break;

                case RECHTS:
                    cprintf("Rechts");
                    break;

                case LINKS:
                    cprintf("Links ");
                    break;
            }

            ausgabe_wo(21,15);
            textattr(30);

            switch(senkrecht)
            {
                case STILLSTAND:
                    cprintf("        ");
                    break;

                case AUFWAERTS:
                    cprintf("Aufwrts");
                    break;

                case ABWAERTS:
                    cprintf("Abwrts ");
                    break;
            }
        }

        /* Das Programm kann entweder mit ESC oder beim anklicken eines    */
        /* Mausschaltkstchens beendet werden.                             */

        /* FALL 1: Der ESC-Taste wird bettigt:                            */

        if(kbhit())                   /* ESC-Taste beendet while-Schleife. */
            schalter=getch();         /* Beim Tastaturereignis wird Ein-   */
                                      /* gabe eingelesen ...               */

        /*  BEACHTEN SIE BITTE!!                                           */
        /*  Bei einem echten zweckmigen Programm knnten Sie weiter      */
        /*  innerhalb der if(kbhit())-Anweisung auch eine Tastaturebene-   */
        /*  Menarbeitung einbauen!!                                       */

        /* FALL 2: Wurde das Schaltkstchen um Mickey-Koordinaten 24,00    */
        /* angeklickt?                                                     */

        if(maus_klick_links())        /* Beim Mausereignis, kontrollieren  */
        {                             /* wir ob die linke Maustaste auf    */
            maus_wo(&x, &y);          /* dem Schaltkstchen an Mickey-     */
            if(x > 16 && x < 32 && y < 8)  /* Koordinaten 24,00 angeklickt */
                schalter = ESC;       /* wurde.  Wenn ja, wird die ESC-    */
        }                             /* Taste emuliert.                   */

        /*  BEACHTEN SIE BITTE!!                                           */
        /*  Bei einem echten zweckmigen Programm knnten Sie an dieser   */
        /*  Stelle weitere Mausoptionen-Verarbeitungen einbauen.  Sie      */
        /*  mssen nur die Bildschirmstelle fr ein Mausereignis in        */
        /*  Mickeys innerhalb einer if(maus_klick_links)- bzw.             */
        /*  if(maus_klick_rechts)-Anweisung als Ereignis-Bedingung ver-    */
        /*  wenden.                                                        */

    }   /* Hier wird die Hauptschleife, d.h. die while(schalter != ESC)-   */
        /* Schleife, beendet.  Alle Tastatur- nzw. Mausoptionen in Men    */
        /* werden wiederholt abgefragt bzw. ausgefhrt bis die ESC-Taste   */
        /* (ASCII 1Bh/27d) bettigt wird oder das Kstchen mit dem Fens-   */
        /* terschlieschalter angeklickt wird.  Im letzten Fall wird der   */
        /* Variablen dem Wert ESC gegeben, genau als ob die ESC-Taste be-  */
        /* ttigt wurde.                                                   */

    _setcursortype(_NORMALCURSOR);    /* Der Textcursor wird vor der Rck- */
                                      /* kehr auf Betriebssystemebene wie- */
                                      /* angeschaltet.                     */
}
/* ENDE Hauptverarbeitungsfunktion verarbeitung() ------------------------ */

/* *********************************************************************** */

/* Steuerungsfunktion main() --------------------------------------------- */

int main(void)
{
    void verabeitung(void);

    _wscroll = 0;
    clrscr();
    rahmen(30,2,1,80,1,25);
    gotoxy(3,1);
    cprintf("[ ]");
    textattr(28);
    gotoxy(4,1);
    cprintf("");
    zentriere(30,1," MAUSDEMO.CPP ");
    zentriere(79,24," Maus auf Kontrollkstchen anklicken oder [ESC]-"\
                    "Taste zu beenden ");
    textattr(23);
    verarbeitung();
    textattr(23);
    clrscr();
    return 0;
}
/* ENDE Steuerungsfunktion main() ---------------------------------------- */



